@@ -1,4 +1,5 @@
 mod add;
+mod edit;
 mod config;
 mod get;
 mod init;
@@ -6,8 +7,11 @@ mod list;
 mod remove;
 
 pub use add::add;
+pub use edit::edit;
+pub use add::add_call;
 pub use config::config;
 pub use get::get;
 pub use init::init;
 pub use list::list;
 pub use remove::remove;
+pub use remove::remove_call;
